Changelog of mopinion-python-api
===================================================


0.0.3 (unreleased)
-------------------


0.0.2 (2021-01-20)
-------------------

- Fixed in documentation.

- Removed travis ci. Integrated GitHub Actions.

- Added coverage into GitHub actions.

0.0.1 (2021-01-20)
-------------------

- Initial project structure.
- Client implementation.
- Test suite.
- Request examples.
